@@ -41,7 +41,9 @@ Document[noskipws]:
 ;
 
 DocumentConfig[noskipws]:
-('SPECIAL_FIELDS:' '\n' special_fields += ConfigSpecialField)?
+  ('VERSION: ' version = /.*$/ '\n')?
+  ('NUMBER: ' number = /.*$/ '\n')?
+  ('SPECIAL_FIELDS:' '\n' special_fields += ConfigSpecialField)?
 ;
 
 ConfigSpecialField[noskipws]:
@@ -119,12 +121,19 @@ MultiLineString:
 ;
 
 Reference[noskipws]:
-  '- TYPE: ' ref_type = ReferenceType '\n'
+  // FileReference is an early, experimental feature. Do not use yet.
+  ParentReqReference | FileReference
+;
+
+ParentReqReference[noskipws]:
+  '- TYPE: ' ref_type = 'Parent' '\n'
   '  VALUE: ' path = /.*$/ '\n'
 ;
 
-ReferenceType[noskipws]:
-  'File' | 'Parent'
+FileReference[noskipws]:
+  // FileReference is an early, experimental feature. Do not use yet.
+  '- TYPE: ' ref_type = 'File' '\n'
+  '  VALUE: ' path = /.*$/ '\n'
 ;
 
 FreeText[noskipws]:
