@@ -3,21 +3,22 @@ import sys
 
 from strictdoc.backend.dsl.reader import SDReader
 from strictdoc.backend.dsl.writer import SDWriter
+from strictdoc.cli.cli_arg_parser import PassthroughCommandConfig
 
 
 class PassthroughAction:
-    def passthrough(self, path_to_doc, output_file):
-        if not os.path.isfile(path_to_doc):
+    def passthrough(self, config: PassthroughCommandConfig):
+        if not os.path.isfile(config.input_file):
             sys.stdout.flush()
             err = "Could not open doc file '{}': No such file or directory".format(
-                path_to_doc
+                config.input_file
             )
             print(err)
             exit(1)
 
-        document = SDReader().read_from_file(path_to_doc)
+        document = SDReader().read_from_file(config.input_file)
 
         writer = SDWriter()
         output = writer.write(document)
-        with open(output_file, "w") as file:
+        with open(config.output_file, "w") as file:
             file.write(output)
