@@ -1,6 +1,7 @@
 from jinja2 import Environment, PackageLoader
 
 from strictdoc.export.html.document_type import DocumentType
+from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 
 
 class DocumentHTMLGenerator:
@@ -14,12 +15,13 @@ class DocumentHTMLGenerator:
         document_tree,
         document,
         traceability_index,
-        markup_renderer,
         link_renderer,
         standalone=False,
     ):
         output = ""
 
+        markup_renderer = MarkupRenderer()
+
         template = DocumentHTMLGenerator.env.get_template(
             "single_document/document.jinja.html"
         )
