@@ -1,6 +1,7 @@
 from jinja2 import Environment, PackageLoader
 
 from strictdoc.export.html.document_type import DocumentType
+from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 
 
 class DocumentDeepTraceHTMLGenerator:
@@ -11,11 +12,11 @@ class DocumentDeepTraceHTMLGenerator:
     env.globals.update(isinstance=isinstance)
 
     @staticmethod
-    def export_deep(
-        document, traceability_index, markup_renderer, link_renderer
-    ):
+    def export_deep(document, traceability_index, link_renderer):
         output = ""
 
+        markup_renderer = MarkupRenderer()
+
         template = DocumentDeepTraceHTMLGenerator.env.get_template(
             "single_document_traceability_deep/document.jinja.html"
         )
