@@ -3,7 +3,15 @@ from enum import Enum
 from functools import partial
 from pathlib import Path
 
+from strictdoc.backend.source_file_syntax.reader import (
+    SourceFileTraceabilityReader,
+)
 from strictdoc.core.document_meta import DocumentMeta
+from strictdoc.core.document_tree import DocumentTree, FileTree
+from strictdoc.core.finders.source_files_finder import (
+    SourceFilesFinder,
+    SourceFile,
+)
 from strictdoc.export.html.generators.document import DocumentHTMLGenerator
 from strictdoc.export.html.generators.document_deep_trace import (
     DocumentDeepTraceHTMLGenerator,
@@ -17,6 +25,9 @@ from strictdoc.export.html.generators.document_trace import (
 from strictdoc.export.html.generators.document_tree import (
     DocumentTreeHTMLGenerator,
 )
+from strictdoc.export.html.generators.source_file_view_generator import (
+    SourceFileViewHTMLGenerator,
+)
 from strictdoc.export.html.renderers.link_renderer import LinkRenderer
 from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 from strictdoc.export.html.tools.html_embedded import HTMLEmbedder
@@ -42,7 +53,7 @@ class HTMLGenerator:
     @staticmethod
     def export_tree(
         formats_string,
-        document_tree,
+        document_tree: DocumentTree,
         traceability_index,
         output_html_root,
         strictdoc_src_path,
@@ -64,7 +75,6 @@ class HTMLGenerator:
         export_options = ExportOptions(
             export_mode, strictdoc_src_path, strictdoc_last_update
         )
-        markup_renderer = MarkupRenderer()
         link_renderer = LinkRenderer(output_html_root)
 
         writer = DocumentTreeHTMLGenerator()
@@ -93,12 +103,26 @@ class HTMLGenerator:
             export_options=export_options,
             document_tree=document_tree,
             traceability_index=traceability_index,
-            markup_renderer=markup_renderer,
             link_renderer=link_renderer,
         )
 
         parallelizer.map(document_tree.document_list, export_binding)
 
+        if document_tree.source_files:
+            print("Generating source files")
+            for source_file in document_tree.source_files:
+                Path(source_file.output_path_dir_full_path).mkdir(
+                    parents=True, exist_ok=True
+                )
+                document_content = SourceFileViewHTMLGenerator.export(
+                    source_file,
+                    document_tree,
+                    traceability_index,
+                    link_renderer,
+                )
+                with open(source_file.output_path_file_full_path, "w") as file:
+                    file.write(document_content)
+
         print(
             "Export completed. Documentation tree can be found at:\n{}".format(
                 output_html_root
@@ -111,7 +135,6 @@ class HTMLGenerator:
         export_options: ExportOptions,
         document_tree,
         traceability_index,
-        markup_renderer,
         link_renderer,
     ):
         document_meta: DocumentMeta = document.meta
@@ -140,7 +163,6 @@ class HTMLGenerator:
                 document,
                 document_tree,
                 traceability_index,
-                markup_renderer,
                 link_renderer,
             )
         return None
@@ -151,7 +173,6 @@ class HTMLGenerator:
         document,
         document_tree,
         traceability_index,
-        markup_renderer,
         link_renderer,
     ):
         document_meta: DocumentMeta = document.meta
@@ -168,7 +189,6 @@ class HTMLGenerator:
                 document_tree,
                 document,
                 traceability_index,
-                markup_renderer,
                 link_renderer,
             )
 
@@ -178,7 +198,7 @@ class HTMLGenerator:
 
             # Single Document Table pages
             document_content = DocumentTableHTMLGenerator.export(
-                document, traceability_index, markup_renderer, link_renderer
+                document, traceability_index, link_renderer
             )
             document_out_file = document_meta.get_html_table_path()
 
@@ -187,7 +207,7 @@ class HTMLGenerator:
 
             # Single Document Traceability pages
             document_content = DocumentTraceHTMLGenerator.export(
-                document, traceability_index, markup_renderer, link_renderer
+                document, traceability_index, link_renderer
             )
             document_out_file = document_meta.get_html_traceability_path()
 
@@ -196,7 +216,7 @@ class HTMLGenerator:
 
             # Single Document Deep Traceability pages
             document_content = DocumentDeepTraceHTMLGenerator.export_deep(
-                document, traceability_index, markup_renderer, link_renderer
+                document, traceability_index, link_renderer
             )
             document_out_file = document_meta.get_html_deep_traceability_path()
 
@@ -212,7 +232,6 @@ class HTMLGenerator:
                 document_tree,
                 document,
                 traceability_index,
-                markup_renderer,
                 link_renderer,
                 standalone=True,
             )
